# lailib

## installation
### Pipy
pip install lailib
### Anaconda
conda install -c learnable lailib

### update package
[Follow internal link](https://learnableai.atlassian.net/wiki/spaces/CV/pages/456884495/update+lailib+to+conda+and+pypi?atlOrigin=eyJpIjoiMDc4MjI5MzBhYWQ0NGMzNGEyYjFmMGMxZjUzODhhNGQiLCJwIjoiYyJ9)
### Requirements
